RDFCalendar.Writers.Writer

Package RDFCalendar :: Module Writers :: Class Writer |
[show private | hide private]
[frames | no frames]

## Class Writer

    Writer --+
             |
            Writer

Method Summary
| `is_attribute_permitted(self, attribute_name, element_name)`
| `is_element_permitted(self, subelement_name, element_name)`
| ``write_attribute`(self, store, attribute_name, attribute)` Write the attribute found in the 'store' with the given 'attribute_name' and represented by 'attribute'.
| `write_uid(self, uid)`
Inherited from Writer
| ``__init__`(self, format_writer)`
| ``write`(self, store, node)` Write, using the 'store', the resource rooted at the given 'node'.
| ``write_element`(self, store, node, node_type)` Write the element found in the 'store' represented by the given 'node' and having the given 'node_type'.

Method Details

### write_attribute(self, store, attribute_name, attribute)
    Write the attribute found in the 'store' with the given 'attribute_name'
    and represented by 'attribute'. This method invokes the format writer's
    'write_attribute' method.

Generated by Epydoc 2.1 on Tue Sep 18 23:33:17 2007 | http://epydoc.sf.net